@@ -33,7 +33,7 @@ int main (int argc, char **argv)
   if (!s) { err = 1; goto beach; }
   fvec_t *vec = new_fvec(hop_size);
 
-  if (samplerate == 0 ) samplerate = aubio_source_get_samplerate(s);
+  samplerate = aubio_source_get_samplerate(s);
 
   do {
     aubio_source_do(s, vec, &read);
