@@ -1,6 +1,6 @@
 #include <aubio.h>
 
-int main ()
+int main (void)
 {
   uint_t samplerate = 16000; // samplerate of signal to filter
   uint_t win_s = 512; // fft size
