@@ -1,13 +1,14 @@
 #include <aubio.h>
 #include "utils_tests.h"
 
-int main ()
+int main (void)
 {
   uint_t i, window_size = 16; // window size
-  utils_init_random();
   cvec_t * complex_vector = new_cvec (window_size); // input buffer
   uint_t rand_times = 4;
 
+  utils_init_random();
+
   while (rand_times -- ) {
     // fill with random phas and norm
     for ( i = 0; i < complex_vector->length; i++ ) {
