@@ -4,7 +4,7 @@
 // Because aubio does not check for double free, this program will crash.
 // Programs that call these functions should check for null pointers.
 
-int main ()
+int main (void)
 {
   del_fvec(NULL);
   del_lvec(NULL);
